==> qtjambi-qt3dcore-5.15.6-sources.jar: io/qt/qt3d/core/QStaticPropertyValueAddedChangeBase.java <==
package io.qt.qt3d.core;


/**
 * <p>The base class for all static PropertyValueAdded QSceneChange events</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueaddedchangebase.html">Qt3DCore::QStaticPropertyValueAddedChangeBase</a></p>
 */
public class QStaticPropertyValueAddedChangeBase extends io.qt.qt3d.core.QPropertyValueAddedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueaddedchangebase.html#QStaticPropertyValueAddedChangeBase">Qt3DCore::QStaticPropertyValueAddedChangeBase::QStaticPropertyValueAddedChangeBase(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    protected QStaticPropertyValueAddedChangeBase(io.qt.qt3d.core.QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QStaticPropertyValueAddedChangeBase instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueaddedchangebase.html#propertyName">Qt3DCore::QStaticPropertyValueAddedChangeBase::propertyName()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String propertyName(){
        return propertyName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String propertyName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueaddedchangebase.html#setPropertyName">Qt3DCore::QStaticPropertyValueAddedChangeBase::setPropertyName(const char*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPropertyName(java.lang.String name){
        setPropertyName_native_const_char_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native void setPropertyName_native_const_char_ptr(long __this__nativeId, java.lang.String name);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStaticPropertyValueAddedChangeBase(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QStaticPropertyValueAddedChangeBase.java <==
package io.qt.qt3d.core;


/**
 * <p>The base class for all static PropertyValueAdded QSceneChange events</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueaddedchangebase.html">Qt3DCore::QStaticPropertyValueAddedChangeBase</a></p>
 */
public class QStaticPropertyValueAddedChangeBase extends io.qt.qt3d.core.QPropertyValueAddedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueaddedchangebase.html#QStaticPropertyValueAddedChangeBase">Qt3DCore::QStaticPropertyValueAddedChangeBase::QStaticPropertyValueAddedChangeBase(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    protected QStaticPropertyValueAddedChangeBase(io.qt.qt3d.core.QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QStaticPropertyValueAddedChangeBase instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueaddedchangebase.html#propertyName">Qt3DCore::QStaticPropertyValueAddedChangeBase::propertyName()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String propertyName(){
        return propertyName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String propertyName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyvalueaddedchangebase.html#setPropertyName">Qt3DCore::QStaticPropertyValueAddedChangeBase::setPropertyName(const char*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setPropertyName(java.lang.String name){
        setPropertyName_native_const_char_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native void setPropertyName_native_const_char_ptr(long __this__nativeId, java.lang.String name);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStaticPropertyValueAddedChangeBase(QPrivateConstructor p) { super(p); } 
    
}
